@@ -106,7 +106,7 @@ func TestMarshaler_Marshal(t *testing.T) {
 					DocumentNamespace:    "http://aquasecurity.github.io/trivy/container_image/rails:latest-3ff14136-e09f-4df9-80ea-000000000001",
 					CreatorOrganizations: []string{"aquasecurity"},
 					CreatorTools:         []string{"trivy"},
-					Created:              "2021-08-25T12:20:30.000000005Z",
+					Created:              "2021-08-25T12:20:30Z",
 				},
 				Packages: map[spdx.ElementID]*spdx.Package2_2{
 					spdx.ElementID("ContainerImage-9396d894cd0cb6cb"): {
@@ -311,7 +311,7 @@ func TestMarshaler_Marshal(t *testing.T) {
 					DocumentNamespace:    "http://aquasecurity.github.io/trivy/container_image/centos:latest-3ff14136-e09f-4df9-80ea-000000000001",
 					CreatorOrganizations: []string{"aquasecurity"},
 					CreatorTools:         []string{"trivy"},
-					Created:              "2021-08-25T12:20:30.000000005Z",
+					Created:              "2021-08-25T12:20:30Z",
 				},
 				Packages: map[spdx.ElementID]*spdx.Package2_2{
 					spdx.ElementID("ContainerImage-413bfede37ad01fc"): {
@@ -464,7 +464,7 @@ func TestMarshaler_Marshal(t *testing.T) {
 					DocumentNamespace:    "http://aquasecurity.github.io/trivy/filesystem/masahiro331/CVE-2021-41098-3ff14136-e09f-4df9-80ea-000000000001",
 					CreatorOrganizations: []string{"aquasecurity"},
 					CreatorTools:         []string{"trivy"},
-					Created:              "2021-08-25T12:20:30.000000005Z",
+					Created:              "2021-08-25T12:20:30Z",
 				},
 				Packages: map[spdx.ElementID]*spdx.Package2_2{
 					spdx.ElementID("Filesystem-5af0f1f08c20909a"): {
@@ -547,7 +547,7 @@ func TestMarshaler_Marshal(t *testing.T) {
 					DocumentNamespace:    "http://aquasecurity.github.io/trivy/repository/test-aggregate-3ff14136-e09f-4df9-80ea-000000000001",
 					CreatorOrganizations: []string{"aquasecurity"},
 					CreatorTools:         []string{"trivy"},
-					Created:              "2021-08-25T12:20:30.000000005Z",
+					Created:              "2021-08-25T12:20:30Z",
 				},
 				Packages: map[spdx.ElementID]*spdx.Package2_2{
 					spdx.ElementID("Repository-7cb7a269a391a798"): {
@@ -622,7 +622,7 @@ func TestMarshaler_Marshal(t *testing.T) {
 					DocumentNamespace:    "http://aquasecurity.github.io/trivy/filesystem/empty/path-3ff14136-e09f-4df9-80ea-000000000001",
 					CreatorOrganizations: []string{"aquasecurity"},
 					CreatorTools:         []string{"trivy"},
-					Created:              "2021-08-25T12:20:30.000000005Z",
+					Created:              "2021-08-25T12:20:30Z",
 				},
 				Packages: map[spdx.ElementID]*spdx.Package2_2{
 					spdx.ElementID("Filesystem-70f34983067dba86"): {
